@@ -25,7 +25,7 @@ from .helpers import BasicAuth
 
 __all__ = ('BaseConnector', 'TCPConnector', 'ProxyConnector', 'UnixConnector')
 
-PY_34 = sys.version_info >= (3, 4)
+PY_341 = sys.version_info >= (3, 4, 1)
 PY_343 = sys.version_info >= (3, 4, 3)
 
 HASHFUNC_BY_DIGESTLEN = {
@@ -53,11 +53,12 @@ class Connection(object):
         if loop.get_debug():
             self._source_traceback = traceback.extract_stack(sys._getframe(1))
 
-    if PY_34:
+    if PY_341:
         def __del__(self):
             if self._transport is not None:
-                if self._loop.is_closed():
-                    return
+                if hasattr(self._loop, 'is_closed'):
+                    if self._loop.is_closed():
+                        return
 
                 self._connector._release(
                     self._key, self._request, self._transport, self._protocol,
@@ -141,7 +142,7 @@ class BaseConnector(object):
 
         self.cookies = http.cookies.SimpleCookie()
 
-    if PY_34:
+    if PY_341:
         def __del__(self):
             if self._closed:
                 return
@@ -222,7 +223,11 @@ class BaseConnector(object):
             return
         self._closed = True
 
-        if not self._loop.is_closed():
+        try:
+            if hasattr(self._loop, 'is_closed'):
+                if self._loop.is_closed():
+                    return
+
             for key, data in self._conns.items():
                 for transport, proto, t0 in data:
                     transport.close()
@@ -233,9 +238,10 @@ class BaseConnector(object):
             if self._cleanup_handle:
                 self._cleanup_handle.cancel()
 
-        self._conns.clear()
-        self._acquired.clear()
-        self._cleanup_handle = None
+        finally:
+            self._conns.clear()
+            self._acquired.clear()
+            self._cleanup_handle = None
 
     @property
     def closed(self):
@@ -512,23 +518,23 @@ class TCPConnector(BaseConnector):
             try:
                 host = hinfo['host']
                 port = hinfo['port']
-                conn = yield from self._loop.create_connection(
+                transp, proto = yield from self._loop.create_connection(
                     self._factory, host, port,
                     ssl=sslcontext, family=hinfo['family'],
                     proto=hinfo['proto'], flags=hinfo['flags'],
                     server_hostname=hinfo['hostname'] if sslcontext else None)
-                transport = conn[0]
-                has_cert = transport.get_extra_info('sslcontext')
+                has_cert = transp.get_extra_info('sslcontext')
                 if has_cert and self._fingerprint:
-                    sock = transport.get_extra_info('socket')
+                    sock = transp.get_extra_info('socket')
                     # gives DER-encoded cert as a sequence of bytes (or None)
                     cert = sock.getpeercert(binary_form=True)
                     assert cert
                     got = self._hashfunc(cert).digest()
                     expected = self._fingerprint
                     if got != expected:
+                        transp.close()
                         raise FingerprintMismatch(expected, got, host, port)
-                return conn
+                return transp, proto
             except OSError as e:
                 exc = e
         else:
