@@ -18,7 +18,7 @@ from aiohttp.connector import Connection
 
 from tests.test_client_functional import Functional
 
-PY_34 = sys.version_info >= (3, 4)
+PY_341 = sys.version_info >= (3, 4)
 
 
 class TestHttpConnection(unittest.TestCase):
@@ -35,7 +35,7 @@ class TestHttpConnection(unittest.TestCase):
     def tearDown(self):
         self.loop.close()
 
-    @unittest.skipUnless(PY_34, "Requires Python 3.4+")
+    @unittest.skipUnless(PY_341, "Requires Python 3.4.1+")
     def test_del(self):
         conn = Connection(
             self.connector, self.key, self.request,
@@ -45,6 +45,8 @@ class TestHttpConnection(unittest.TestCase):
 
         with self.assertWarns(ResourceWarning):
             del conn
+            gc.collect()
+
         self.connector._release.assert_called_with(self.key,
                                                    self.request,
                                                    self.transport,
@@ -116,8 +118,9 @@ class TestBaseConnector(unittest.TestCase):
 
     def tearDown(self):
         self.loop.close()
+        gc.collect()
 
-    @unittest.skipUnless(PY_34, "Requires Python 3.4+")
+    @unittest.skipUnless(PY_341, "Requires Python 3.4.1+")
     def test_del(self):
         conn = aiohttp.BaseConnector(loop=self.loop)
         transp = unittest.mock.Mock()
@@ -129,6 +132,7 @@ class TestBaseConnector(unittest.TestCase):
 
         with self.assertWarns(ResourceWarning):
             del conn
+            gc.collect()
 
         self.assertFalse(conns_impl)
         transp.close.assert_called_with()
@@ -138,7 +142,7 @@ class TestBaseConnector(unittest.TestCase):
             msg['source_traceback'] = unittest.mock.ANY
         exc_handler.assert_called_with(self.loop, msg)
 
-    @unittest.skipUnless(PY_34, "Requires Python 3.4+")
+    @unittest.skipUnless(PY_341, "Requires Python 3.4.1+")
     def test_del_with_scheduled_cleanup(self):
         conn = aiohttp.BaseConnector(loop=self.loop, keepalive_timeout=0.01)
         transp = unittest.mock.Mock()
@@ -162,7 +166,7 @@ class TestBaseConnector(unittest.TestCase):
             msg['source_traceback'] = unittest.mock.ANY
         exc_handler.assert_called_with(self.loop, msg)
 
-    @unittest.skipUnless(PY_34, "Requires Python 3.4+")
+    @unittest.skipUnless(PY_341, "Requires Python 3.4.1+")
     def test_del_with_closed_loop(self):
         conn = aiohttp.BaseConnector(loop=self.loop)
         transp = unittest.mock.Mock()
@@ -182,7 +186,7 @@ class TestBaseConnector(unittest.TestCase):
         self.assertFalse(transp.close.called)
         self.assertTrue(exc_handler.called)
 
-    @unittest.skipUnless(PY_34, "Requires Python 3.4+")
+    @unittest.skipUnless(PY_341, "Requires Python 3.4.1+")
     def test_del_empty_conector(self):
         conn = aiohttp.BaseConnector(loop=self.loop)
 
@@ -502,7 +506,10 @@ class TestBaseConnector(unittest.TestCase):
                     self.assertEqual(exc.got, testcases[i-1])
                 else:
                     # should not raise
-                    self.loop.run_until_complete(coro)
+                    resp = self.loop.run_until_complete(coro)
+                    resp.close(force=True)
+
+            conn.close()
 
     def test_tcp_connector_clear_resolved_hosts(self):
         conn = aiohttp.TCPConnector(loop=self.loop)
@@ -746,7 +753,8 @@ class TestHttpClientConnector(unittest.TestCase):
     def test_connector_cookie_deprecation(self):
         with self.assertWarnsRegex(DeprecationWarning,
                                    "^Using `share_cookies` is deprecated"):
-            aiohttp.TCPConnector(share_cookies=True, loop=self.loop)
+            conn = aiohttp.TCPConnector(share_cookies=True, loop=self.loop)
+        conn.close()
 
 
 class TestProxyConnector(unittest.TestCase):
@@ -962,6 +970,10 @@ class TestProxyConnector(unittest.TestCase):
         tr.pause_reading.assert_called_once_with()
         tr.get_extra_info.assert_called_with('socket', default=None)
 
+        proxy_req.close()
+        proxy_resp.close()
+        req.close()
+
     @unittest.mock.patch('aiohttp.connector.ClientRequest')
     def test_https_connect_runtime_error(self, ClientRequestMock):
         loop_mock = unittest.mock.Mock()
@@ -988,6 +1000,10 @@ class TestProxyConnector(unittest.TestCase):
                 RuntimeError, "Transport does not expose socket instance"):
             self.loop.run_until_complete(connector._create_connection(req))
 
+        proxy_req.close()
+        proxy_resp.close()
+        req.close()
+
     @unittest.mock.patch('aiohttp.connector.ClientRequest')
     def test_https_connect_http_proxy_error(self, ClientRequestMock):
         loop_mock = unittest.mock.Mock()
@@ -1015,6 +1031,10 @@ class TestProxyConnector(unittest.TestCase):
                 aiohttp.HttpProxyError, "400, message='bad request'"):
             self.loop.run_until_complete(connector._create_connection(req))
 
+        proxy_req.close()
+        proxy_resp.close()
+        req.close()
+
     @unittest.mock.patch('aiohttp.connector.ClientRequest')
     def test_https_connect_resp_start_error(self, ClientRequestMock):
         loop_mock = unittest.mock.Mock()
